delete

package
v0.6.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Delete

func Delete(path string) error

Delete removes a scan history file with escape guards

func DeleteDir

func DeleteDir(dirPath string) error

DeleteDir removes all .json files in a directory with escape guards

func SafeDelete

func SafeDelete(path, baseDir string) error

SafeDelete removes a file, ensuring it's within an allowed base directory

func SafeDeleteDir

func SafeDeleteDir(dirPath, baseDir string) error

SafeDeleteDir removes all .json files in a directory within a base directory

Types

This section is empty.

Jump to