paths

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Dir

func Dir() (string, error)

Dir returns the base history directory path

func FormatCIDR

func FormatCIDR(cidr string) string

FormatCIDR converts a CIDR like "192.168.1.0/24" to "192.168.1.0_24"

func Scan

func Scan(interfaceName, cidr string, timestamp time.Time) (string, error)

Scan builds the full path for a scan file

func ScanDir

func ScanDir(interfaceName, cidr string) (string, error)

ScanDir returns the directory path for a specific interface/CIDR combination

Types

This section is empty.

Jump to