Documentation
¶
Index ¶
Constants ¶
const ( NodeInterface = historytree.NodeInterface NodeNetwork = historytree.NodeNetwork NodeScan = historytree.NodeScan )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Model ¶
type Model struct {
Mode ViewMode
Tree []*TreeNode
FlatList []*TreeNode // Flattened view of expanded tree
Cursor int
ShowHelp bool
DeleteDialog *delete.HistoryDeleteDialog // nil when not shown
ErrorMsg string
Viewport viewport.Model
ListOffset int
WindowW int
WindowH int
Details detailsview.Model
DetailCursors map[string]int // remembered host cursor per scan file path
HoveredHelpItem int // -1 means no hover, otherwise index of helpline item
HelpLineY int // Y row where the helpline starts, set during render
}
func StartDetailRescan ¶
func (Model) HandleMouse ¶
func (m Model) HandleMouse(msg tea.Msg, maxWidth int) UpdateResult
HandleMouse processes mouse events for the history list view. Scroll wheel scrolls the list; clicking a row selects or toggles it.
func (Model) SetListViewportSize ¶
SetViewportSize initializes or updates the main viewport for list view accounting for title, spacing, and help text that appear outside the viewport
type NodeType ¶
type NodeType = historytree.NodeType
type ScanCounts ¶
type ScanCounts = historytree.ScanCounts
type TreeNode ¶
type TreeNode = historytree.Node
type UpdateResult ¶
Source Files
¶
Click to show internal directories.
Click to hide internal directories.