Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ToggleMode ¶
Types ¶
type Action ¶
type Model ¶
type Model struct {
ShowHelp bool
PortPack string
CustomPorts string
CustomCursor int
PortInput common.CustomPortInput
ErrorMsg string
NetworkScan shared.Scanner
HoveredHelpItem int // -1 means no hover, otherwise index of helpline item
HelpLineY int // Y row where the helpline starts, set during render
}
func (Model) HandleMouse ¶
HandleMouse processes a mouse event for the ports view. Clicking the default or custom row selects it; clicking the active row applies.
Click to show internal directories.
Click to hide internal directories.